==> ws-v3.70.10-src.tar.gz: ws-v3.70-10/include/nx/WSDnxCodeConvert.h <==
//
// Copyright (C) 1999-2002 Toshikaz Hirabayashi
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to
// deal in the Software without restriction, including without limitation the
// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
// sell copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
// TOSHIKAZ HIRABAYASHI BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
// OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.
// Except as contained in this notice, the name of Toshikaz Hirabayashi shall
// not be used in advertising or otherwise to promote the sale, use or other
// dealings in this Software without prior written authorization from
// Toshikaz Hirabayashi.

#ifndef WSDNXCODECONVERT_H
#define WSDNXCODECONVERT_H

#include <WScom.h>
#include <WSDimage.h>
#include <WSClistData.h>
#include <WSCindexData.h>
#include <WSClocaleSet.h>

class WSDnxCodeConvert: public WSDcodeConvert{
  public:
virtual int codeConvert(char*,int,int,const char*,int,int);
virtual int getSystemLocale();
virtual void initialize();
virtual int utf8CharLen(const char*,int);
virtual int encode(WSCushort*,int,const char*,int,int);
virtual int decode(char* dest,int,const WSCushort*,int,int);
};

#endif

==> ws-v3.80.5-src.tar.gz: ws-v3.80-5/include/nx/WSDnxCodeConvert.h <==
//
// Copyright (C) 1999-2004 WideStudio Development Team
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to
// deal in the Software without restriction, including without limitation the
// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
// sell copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
// WIDESTUDIO DEVELOPMENT TEAM BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.
// Except as contained in this notice, the name of WideStudio Development Team
// shall not be used in advertising or otherwise to promote the sale, use or
// other dealings in this Software without prior written authorization from
// WideStudio Development Team.

#ifndef WSDNXCODECONVERT_H
#define WSDNXCODECONVERT_H

#include <WScom.h>
#include <WSDimage.h>
#include <WSClistData.h>
#include <WSCindexData.h>
#include <WSClocaleSet.h>

class WSDnxCodeConvert: public WSDcodeConvert{
  public:
virtual int codeConvert(char*,int,int,const char*,int,int);
virtual int getSystemEncoding();
virtual void initialize();
virtual int utf8CharLen(const char*,int);
virtual int encode(WSCushort*,int,const char*,int,int);
virtual int decode(char* dest,int,const WSCushort*,int,int);
};

#endif
